### Your checklist for this pull request

📣 Please review the [contribution guidelines](https://qmat.readthedocs.io/en/latest/contributing.html) of this package.

- [ ] Please check first that [all test pass locally and coverage is still 100%](https://qmat.readthedocs.io/en/latest/devdoc/testing.html)
- [ ] Make sure you are requesting to **pull a topic/feature/bugfix branch** (right side). Don't request your master !
- [ ] Make sure you are making a pull request against the **main branch** (left side). Also you should start *your branch* off *our main branch*.

### Description

Short concise description of your contribution

🤓 Thank you !
